import { Component, OnInit } from '@angular/core';
import { CommonModule } from '@angular/common';
import { FormsModule } from '@angular/forms';
import { ConfigService } from '../../services/config.service';
import { SystemConfig } from '../../model/SystemConfig';


@Component({
  selector: 'app-config',
  templateUrl: './config.component.html',
  styleUrls: ['./config.component.css'],
  imports: [CommonModule, FormsModule]
})
export class ConfigComponent implements OnInit {
  config: SystemConfig = {
    max_image_size: 8 * 1024 * 1024,
    max_images_per_pin: 10,
    max_images_per_user: 100,
    allowed_image_types: ['image/jpeg', 'image/png', 'image/gif', 'image/webp'],
    max_pins_per_user: 50,
    max_friends_per_user: 100
  };

  localImageTypes: string[] = [];

  constructor(private configService: ConfigService) {}

  ngOnInit(): void {
    this.loadConfig();
  }

  loadConfig(): void {
    this.configService.loadConfig().subscribe(config => {
      this.config = config;
      this.localImageTypes = [...config.allowed_image_types];
    });
  }

  saveConfig(): void {
    this.config.allowed_image_types = [...this.localImageTypes];
    this.configService.saveConfig(this.config).subscribe(config => {
      this.config = config;
      this.localImageTypes = [...config.allowed_image_types];
      alert('Configuration enregistrée avec succès');
    });
  }

  resetConfig(): void {
    this.loadConfig();
  }

  addImageType(): void {
    this.localImageTypes.push('');
  }

  removeImageType(index: number): void {
    this.localImageTypes.splice(index, 1);
  }

  updateImageType(index: number, event: Event): void {
    const input = event.target as HTMLInputElement;
    this.localImageTypes[index] = input.value;
  }
} 